sumo.phonon package
====================

Module contents
---------------

.. automodule:: sumo.phonon
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

sumo.phonon.phonopy module
---------------------------

.. automodule:: sumo.phonon.phonopy
    :members:
    :undoc-members:
    :show-inheritance:
